@@ -3,7 +3,6 @@ use std::os::unix::io::{AsRawFd, RawFd};
 use std::pin::Pin;
 use std::task::{Context, Poll};
 
-use crate::driver::buffers::ProvidedBuf;
 use crate::driver::{self, Action};
 
 use crate::driver::DEFAULT_BUFFER_SIZE;
@@ -19,7 +18,7 @@ impl<T: AsRawFd> Stream<T> {
             io,
             inner: Inner {
                 read_pos: 0,
-                rd: ProvidedBuf::default(),
+                rd: vec![],
                 read: Read::Idle,
                 write: Write::Idle,
             },
@@ -52,7 +51,7 @@ impl<T: AsRawFd> Stream<T> {
 }
 
 struct Inner {
-    rd: ProvidedBuf,
+    rd: Vec<u8>,
     read_pos: usize,
     read: Read,
     write: Write,
@@ -94,7 +93,7 @@ impl Inner {
                     }
 
                     self.read_pos = 0;
-                    self.rd = ProvidedBuf::default();
+                    self.rd = vec![];
                     let action = Action::read(fd, DEFAULT_BUFFER_SIZE as u32)?;
                     self.read = Read::Reading(action);
                 }
